Sphinx probs_rdf extension
==========================

This extension adds directives to Sphinx for adding Processes and Objects to a PRObs ontology system definition.

License
-------

sphinx_probs_rdf is licensed with the `MIT license <LICENSE>`_.

Acknowledgements
----------------

Thanks to the `sphinxcontrib repositories`_ for inspiration on how to set up, package and test a Sphinx extension.

.. _sphinxcontrib repositories: https://github.com/sphinx-doc/sphinxcontrib-jsmath
